@@ -5,6 +5,7 @@ Inheritance diagram:
 .. inheritance-diagram:: ipyparallel.error
     :parts: 3
 """
+
 import builtins
 import sys
 import traceback
@@ -181,7 +182,7 @@ class CompositeError(RemoteError):
         else:
             try:
                 en, ev, etb, ei = self.elist[excid]
-            except:
+            except Exception:
                 raise IndexError("an exception with index %i does not exist" % excid)
             else:
                 lines.append(self._get_engine_str(ei) + ":")
@@ -195,7 +196,7 @@ class CompositeError(RemoteError):
     def raise_exception(self, excid=0):
         try:
             en, ev, etb, ei = self.elist[excid]
-        except:
+        except Exception:
             raise IndexError("an exception with index %i does not exist" % excid)
         else:
             raise RemoteError(en, ev, etb, ei)
@@ -243,7 +244,7 @@ def collect_exceptions(rdict_or_list, method='unspecified'):
     if len(elist) == 0:
         return rdict_or_list
     else:
-        msg = "one or more exceptions raised in: %s" % (method)
+        msg = f"one or more exceptions raised in: {method}"
         err = CompositeError(msg, elist)
         raise err
 
